tag.c
changeset 80 8125f908c80c
parent 76 4bd49f404f10
child 84 052fe7498930
--- a/tag.c	Sat Jul 15 18:51:44 2006 +0200
+++ b/tag.c	Sun Jul 16 00:47:40 2006 +0200
@@ -17,7 +17,7 @@
 };
 
 static Rule rule[] = {
 	/* class			instance	tags						dofloat */
 	{ "Firefox-bin",	"Gecko",	{ [Twww] = "www" },			False },
 };
 
@@ -67,7 +67,7 @@
 	w = sw - mw;
 	arrange = dotile;
 	for(n = 0, c = clients; c; c = c->next)
-		if(c->tags[tsel] && !c->dofloat)
+		if(c->tags[tsel] && !c->isfloat)
 			n++;
 
 	if(n > 1)
@@ -77,7 +77,7 @@
 
 	for(i = 0, c = clients; c; c = c->next) {
 		if(c->tags[tsel]) {
-			if(c->dofloat) {
+			if(c->isfloat) {
 				higher(c);
 				resize(c, True);
 				continue;
@@ -155,7 +155,7 @@
 				{
 					for(j = 0; j < TLast; j++)
 						c->tags[j] = rule[i].tags[j];
-					c->dofloat = rule[i].dofloat;
+					c->isfloat = rule[i].isfloat;
 					matched = True;
 					break;
 				}
@@ -17,7 +17,7 @@
 
 static Rule rule[] = {
-	/* class			instance	tags						dofloat */
+	/* class			instance	tags						isfloat */
 	{ "Firefox-bin",	"Gecko",	{ [Twww] = "www" },			False },
 };